window.Gleam.initSearch([{"doc":"survey","title":"survey","content":"# survey\n\n[![Package Version](https://img.shields.io/hexpm/v/survey)](https://hex.pm/packages/survey)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/survey/)\n\nA library to easily create rich and interactive prompts in the terminal.\n\nInpired by [`AlecAivazis/survey`](https://github.com/AlecAivazis/survey)\n\nUse `survey.Question` for `String` input and `survey.Confirmation` for `Bool` input.\n\n```sh\ngleam add survey\n```\n```gleam\nimport survey\nimport gleam/option.{type Option, None, Some}\n\npub fn main() {\n  let assert [\n    #(&quot;first_name&quot;, survey.StringAnswer(first_name)),\n    #(&quot;last_name&quot;, survey.StringAnswer(last_name)),\n    #(&quot;survey_fan&quot;, survey.BoolAnswer(survey_fan)),\n  ] =\n    [\n      #(\n        &quot;first_name&quot;,\n        survey.new_question(\n          prompt: &quot;First Name:&quot;,\n          help: Some(&quot;Please enter your first name&quot;),\n          default: None,\n          validate: None,\n          transform: None,\n        ),\n      ),\n      #(\n        &quot;last_name&quot;,\n        survey.new_question(\n          prompt: &quot;Last Name:&quot;,\n          help: Some(&quot;Please enter your last name&quot;),\n          default: None,\n          validate: None,\n          transform: None,\n        ),\n      ),\n      #(\n        &quot;survey_fan&quot;,\n        survey.new_confirmation(\n          prompt: &quot;Are you a survey fan?:&quot;,\n          help: Some(&quot;It&#39;s a great library&quot;),\n          default: Some(True),\n          transform: Some(fn(_: Bool) -&gt; Bool { True }),\n        ),\n      ),\n    ]\n    |&gt; survey.ask_many\n\n  case survey_fan {\n    True -&gt; io.println(&quot;Hello, &quot; &lt;&gt; first_name &lt;&gt; &quot; &quot; &lt;&gt; last_name &lt;&gt; &quot;!&quot;)\n    False -&gt; io.println(&quot;I don&#39;t believe you&quot;)\n  }\n}\n```\n\n```sh\n⟩ gleam run\n   Compiled in 0.02s\n    Running survey.main\nFirst Name: Survey\nLast Name: User\nAre you a survey fan?: [Y/n] \nHello, Survey User!\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/survey&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n","url":"index.html"},{"doc":"survey","title":"Answer","content":"pub type Answer {\n  StringAnswer(String)\n  BoolAnswer(Bool)\n  AnswerError(AskError)\n  NoAnswer\n}\n Answer is used to have different result types for Questions and Confirmations. Also allows handling errors\nStringAnswer(String)\n\n\nBoolAnswer(Bool)\n\n\nAnswerError(AskError)\n\n\nNoAnswer\n\n\nSynonyms:\nsurvey.Answer\nsurvey Answer","url":"survey.html#Answer"},{"doc":"survey","title":"AskError","content":"pub type AskError {\n  Input\n  InvalidType\n  Validation\n}\n AskError are different errors that could occur when handling prompts\nInput\n\n\nInvalidType\n\n\nValidation\n\n\nSynonyms:\nsurvey.AskError\nsurvey AskError","url":"survey.html#AskError"},{"doc":"survey","title":"Survey","content":"pub type Survey {\n  Question(\n    prompt: String,\n    help: Option(String),\n    default: Option(String),\n    validate: Option(fn(String) -&gt; Bool),\n    transform: Option(fn(String) -&gt; String),\n  )\n  Confirmation(\n    prompt: String,\n    help: Option(String),\n    default: Option(Bool),\n    transform: Option(fn(Bool) -&gt; Bool),\n  )\n}\n Configure a survey prompt to present to the user.\n \n Question allows receiving freeform String responses\n \n Confirmation presents the user with a [y/n] prompt to record a Bool response\nQuestion(\n  prompt: String,\n  help: Option(String),\n  default: Option(String),\n  validate: Option(fn(String) -&gt; Bool),\n  transform: Option(fn(String) -&gt; String),\n)\n Question allows receiving freeform String responses\n   - `prompt`: printed prompt so the user knows expectations\n   - `help`: optional help message to display if input is invalid or using `ask(help: True)`\n   - `default`: optional default to use if empty input is received. If this is None, then input is required\n   - `validate`: optional validation function to determine if input is acceptable\n   - `transform`: optional transformation function to modify input\n\nConfirmation(\n  prompt: String,\n  help: Option(String),\n  default: Option(Bool),\n  transform: Option(fn(Bool) -&gt; Bool),\n)\n Confirmation presents the user with a [y/n] prompt to record a Bool response\n   - `prompt`: printed prompt so the user knows expectations\n   - `help`: optional help message to display if input is invalid or using `ask(help: True)`\n   - `default`: optional default to use if empty input is received. If this is None, then input is required.\n     - `[y/n]`, `[Y/n]`, `[y/N]` are added to the prompt for default None, True, and False respectively\n   - `transform`: optional transformation function to modify input\n\nSynonyms:\nsurvey.Survey\nsurvey Survey","url":"survey.html#Survey"},{"doc":"survey","title":"ask","content":"pub fn ask(q: Survey, help: Bool) -&gt; Answer\n ask will present the user with a prompt and handle the Answer\nSynonyms:\nsurvey.ask\nsurvey ask","url":"survey.html#ask"},{"doc":"survey","title":"ask_fn","content":"pub fn ask_fn(\n  q: Survey,\n  help: Bool,\n  get_line: fn(String) -&gt; Result(String, AskError),\n) -&gt; Answer\n same as `ask`, but allows providing a custom input handler\nSynonyms:\nsurvey.ask_fn\nsurvey ask_fn","url":"survey.html#ask_fn"},{"doc":"survey","title":"ask_many","content":"pub fn ask_many(\n  qs: List(#(String, Survey)),\n  help: Bool,\n) -&gt; List(#(String, Answer))\n ask_many allows presenting the user with many prompts sequentially\nSynonyms:\nsurvey.ask_many\nsurvey ask_many","url":"survey.html#ask_many"},{"doc":"survey","title":"ask_many_fn","content":"pub fn ask_many_fn(\n  qs: List(#(String, Survey)),\n  help: Bool,\n  get_lines: List(fn(String) -&gt; Result(String, AskError)),\n) -&gt; List(#(String, Answer))\n same as `ask_many`, but allows providing a custom input handler\nSynonyms:\nsurvey.ask_many_fn\nsurvey ask_many_fn","url":"survey.html#ask_many_fn"},{"doc":"survey","title":"new_confirmation","content":"pub fn new_confirmation(\n  prompt prompt: String,\n  help help: Option(String),\n  default default: Option(Bool),\n  transform transform: Option(fn(Bool) -&gt; Bool),\n) -&gt; Survey\n Constructor for a Confirmation that can make code more readable with labelled arguments\n\n ## Example\n\n \n survey.new_confirmation(\n   prompt: &quot;Are you a survey fan?:&quot;,\n   help: Some(&quot;It&#39;s a great library&quot;),\n   default: Some(True),\n   transform: Some(fn(_: Bool) -&gt; Bool { True }),\n ),\n \nSynonyms:\nsurvey.new_confirmation\nsurvey new_confirmation","url":"survey.html#new_confirmation"},{"doc":"survey","title":"new_question","content":"pub fn new_question(\n  prompt prompt: String,\n  help help: Option(String),\n  default default: Option(String),\n  validate validate: Option(fn(String) -&gt; Bool),\n  transform transform: Option(fn(String) -&gt; String),\n) -&gt; Survey\n Constructor for a Question that can make code more readable with labelled arguments\n\n ## Example\n\n \n survey.new_question(\n   prompt: &quot;First Name:&quot;,\n   help: Some(&quot;Please enter your first name&quot;),\n   default: None,\n   validate: None,\n   transform: None,\n ),\n \nSynonyms:\nsurvey.new_question\nsurvey new_question","url":"survey.html#new_question"},{"doc":"survey","title":"survey","content":"","url":"survey.html"}]);